diff --git a/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/.ratings b/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/.ratings
index d79c844bc6011b35d20b3be8f49e27ca60915e26..41818f50c2fada591e50ac75f6a66513eb2f4fc0 100644
--- a/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/.ratings
+++ b/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/.ratings
@@ -1,6 +1,6 @@
 DiamondContentVisualBase.java a81e76e85706ad38b6c22bbcd1cc5a5696737e3d GREEN
 LineLinkGraph.java 85a06a553f88f7b9fb4bd9c06411725d9fb160fc GREEN
-LineLinkVisualBase.java b4d2288481a38bd1b2e3dacd49c4a2d602255096 RED
+LineLinkVisualBase.java 876d6872b1844568f055809b975d2471330f719f YELLOW
 LineSegment.java 9ab1b97ad372db763654ef783747fa0733bec55c GREEN
 RectangularBorderLocation.java 824472c353534d1094ae4f735a30a231b885f050 GREEN
 RectangularContentAnchorageVisualBase.java 39981dc29cac42d77c6ffe855ecc8ccad1689230 GREEN
diff --git a/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/LineLinkVisualBase.java b/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/LineLinkVisualBase.java
index b4d2288481a38bd1b2e3dacd49c4a2d602255096..876d6872b1844568f055809b975d2471330f719f 100644
--- a/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/LineLinkVisualBase.java
+++ b/org.fortiss.tooling.common.ui/src/org/fortiss/tooling/common/ui/javafx/lwfxef/visual/rectangular/LineLinkVisualBase.java
@@ -71,7 +71,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 			double ny = bp.getY() + chg.getDeltaY();
 			segments.add(new LineSegment(bpModel, sx, sy, nx, ny, getInvisibleSelectionLineWidth(),
 					feedbackSize, false, false, 0, getLabelText(i, pts + 1),
-					getSimluationLabelText(i, pts + 1)));
+					getSimulationLabelText(i, pts + 1)));
 			sx = nx;
 			sy = ny;
 			bpModel = getBendPointModel(i);
@@ -82,7 +82,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 		segments.add(new LineSegment(bpModel, sx, sy, endPoint.getX(), endPoint.getY(),
 				getInvisibleSelectionLineWidth(), 0, showArrowOnLastSegment(), useLineArrow(),
 				getArrowLength(), getLabelText(pts, pts + 1),
-				getSimluationLabelText(pts, pts + 1)));
+				getSimulationLabelText(pts, pts + 1)));
 		endFeedbackHandle.setX(endPoint.getX() - fs2);
 		endFeedbackHandle.setY(endPoint.getY() - fs2);
 		endFeedbackHandle.setWidth(feedbackSize);
@@ -93,7 +93,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 		for(int i = 0; i < numberOfSegs; i++) {
 			LineSegment ls = segments.get(i);
 			ls.addLinkNodes(layers, bundle, getLabelText(i, numberOfSegs),
-					getSimluationLabelText(i, numberOfSegs));
+					getSimulationLabelText(i, numberOfSegs));
 		}
 		linesAddedToSceneGraph = true;
 	}
@@ -160,7 +160,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 		for(int i = 0; i < pts; i++) {
 			Point2D ep = getFeedbackChangeForBendPoint(i).applyToPoint(getBendPointLocation(i));
 			segments.get(segIndex).update(sp, ep, feedbackSize, 0, getLabelText(i, pts),
-					getSimluationLabelText(i, pts));
+					getSimulationLabelText(i, pts));
 			sp = ep;
 			segIndex++;
 		}
@@ -168,7 +168,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 		Point2D ep = getFeedbackChangeForBendPoint(END_OF_LINK_BEND_POINT_INDEX)
 				.applyToPoint(getEndAnchorPoint());
 		segments.get(segIndex).update(sp, ep, 0, getArrowLength(), getLabelText(pts, pts),
-				getSimluationLabelText(pts, pts));
+				getSimulationLabelText(pts, pts));
 		endFeedbackHandle.setX(ep.getX() - fs2);
 		endFeedbackHandle.setY(ep.getY() - fs2);
 		endFeedbackHandle.setWidth(feedbackSize);
@@ -366,7 +366,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 	}
 
 	/**
 	 * Returns the label text.
 	 * 
 	 * @param currentSegment
 	 *            the current segment
@@ -374,8 +374,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 	 *            the last index of a segment
 	 * @return the label text for the current segment or null for no label
 	 */
-	// TODO (TM): Correct typo in function name (here and in other classes accessing the method)
-	protected String getSimluationLabelText(int currentSegment, int lastSegment) {
+	protected String getSimulationLabelText(int currentSegment, int lastSegment) {
 		return null;
 	}
@@ -366,7 +366,7 @@ public abstract class LineLinkVisualBase extends LinkVisualBase {
 
 	/**
-	 * Returns the label text.
+	 * Returns the simulation label text.
 	 * 
 	 * @param currentSegment